==> Xbae-4.4.tar.gz: Xbae-4.4/src/Shadow.h <==
/*
 * Copyright(c) 1992 Bell Communications Research, Inc. (Bellcore)
 *                        All rights reserved
 * Permission to use, copy, modify and distribute this material for
 * any purpose and without fee is hereby granted, provided that the
 * above copyright notice and this permission notice appear in all
 * copies, and that the name of Bellcore not be used in advertising
 * or publicity pertaining to this material without the specific,
 * prior written permission of an authorized representative of
 * Bellcore.
 *
 * BELLCORE MAKES NO REPRESENTATIONS AND EXTENDS NO WARRANTIES, EX-
 * PRESS OR IMPLIED, WITH RESPECT TO THE SOFTWARE, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR ANY PARTICULAR PURPOSE, AND THE WARRANTY AGAINST IN-
 * FRINGEMENT OF PATENTS OR OTHER INTELLECTUAL PROPERTY RIGHTS.  THE
 * SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT SHALL BELLCORE OR
 * ANY OF ITS AFFILIATES BE LIABLE FOR ANY DAMAGES, INCLUDING ANY
 * LOST PROFITS OR OTHER INCIDENTAL OR CONSEQUENTIAL DAMAGES RELAT-
 * ING TO THE SOFTWARE.
 *
 */

/*
 * Shadow.h created by Andrew Lister (30 October, 1995)
 */

#ifndef _Xbae_Shadow_h
#define _Xbae_Shadow_h

#include <Xbae/Macros.h>
void xbaeDrawGridShadows P(( XbaeMatrixWidget mw,
			     unsigned int redraw_reason ));
void xbaeDrawRowShadow P(( XbaeMatrixWidget mw, int row,
			   unsigned int redraw_reason ));
void xbaeDrawColumnShadow P(( XbaeMatrixWidget mw, int column,
			      unsigned int redraw_reason ));

#endif

==> Xbae-4.7.tar.gz: Xbae-4.7/src/Shadow.h <==
/*
 * Copyright(c) 1992 Bell Communications Research, Inc. (Bellcore)
 * Copyright(c) 1995-99 Andrew Lister
 *                        All rights reserved
 * Permission to use, copy, modify and distribute this material for
 * any purpose and without fee is hereby granted, provided that the
 * above copyright notice and this permission notice appear in all
 * copies, and that the name of Bellcore not be used in advertising
 * or publicity pertaining to this material without the specific,
 * prior written permission of an authorized representative of
 * Bellcore.
 *
 * BELLCORE MAKES NO REPRESENTATIONS AND EXTENDS NO WARRANTIES, EX-
 * PRESS OR IMPLIED, WITH RESPECT TO THE SOFTWARE, INCLUDING, BUT
 * NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR ANY PARTICULAR PURPOSE, AND THE WARRANTY AGAINST IN-
 * FRINGEMENT OF PATENTS OR OTHER INTELLECTUAL PROPERTY RIGHTS.  THE
 * SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT SHALL BELLCORE OR
 * ANY OF ITS AFFILIATES BE LIABLE FOR ANY DAMAGES, INCLUDING ANY
 * LOST PROFITS OR OTHER INCIDENTAL OR CONSEQUENTIAL DAMAGES RELAT-
 * ING TO THE SOFTWARE.
 *
 * $Id: Shadow.h,v 1.8 1999/07/24 02:03:49 lister Exp $
 */

/*
 * Shadow.h created by Andrew Lister (30 October, 1995)
 */

#ifndef _Xbae_Shadow_h
#define _Xbae_Shadow_h

#include <Xbae/Macros.h>

void xbaeDrawCellShadow P((XbaeMatrixWidget, Window, int, int, int, int,
			    int, int, Boolean, Boolean, Boolean));

#if XmVersion >= 1002
void xbaeDrawCellHighlight P((XbaeMatrixWidget, Window, GC, int, int, int,
			       int, int, int, int));
#endif
#endif
